@@ -92,7 +92,7 @@ class APIRequestor:
             api_key = api_key
 
         if api_key is None:
-            raise error.MalformedAuthorizationError(message_body="Missing API key")
+            raise error.MalformedAuthorizationError(message="Missing API key")
 
         # best effort to populate proxy_url?
         proxy_url = self.proxy_url or circle.proxy_url
@@ -101,6 +101,7 @@ class APIRequestor:
 
         if method in (
             "post",
+            "put",
             "patch",
         ):
             params.setdefault("idempotencyKey", uuid.uuid4().__str__())
